@@ -88,10 +88,10 @@ protected:
   virtual void set_document_modified(bool bModified = true);
   
   ///bool indicates success.
-  virtual bool open_document(const Glib::ustring& strFilepath);
+  virtual bool open_document(const Glib::ustring& file_uri);
 
-  virtual void document_history_add(const Glib::ustring& strFilepath);
-  virtual void document_history_remove(const Glib::ustring& strFilepath);
+  virtual void document_history_add(const Glib::ustring& file_uri);
+  virtual void document_history_remove(const Glib::ustring& file_uri);
 
 public: // We can not take function pointers of these methods in a 
         // derived class, if they are protected - for instance, with sigc::mem_fun()
@@ -131,12 +131,18 @@ protected:
 
   virtual void ui_warning(const Glib::ustring& text) = 0;
   virtual Glib::ustring ui_file_select_open() = 0;
-  virtual Glib::ustring ui_file_select_save(const Glib::ustring& old_filepath) = 0;
+
+  /** Present a user interface that allows the user to select a location to save the file.
+   * @param old_file_uri The existing URI of the file, if any.
+   * @result The URI of the file chosen by the user.
+   */
+  virtual Glib::ustring ui_file_select_save(const Glib::ustring& old_file_uri) = 0;
+  
   virtual void ui_show_modification_status() = 0;
 
   virtual enumSaveChanges ui_offer_to_save_changes() = 0;
 
-  virtual bool ui_ask_overwrite(const std::string& filepath) = 0;
+  virtual bool ui_ask_overwrite(const std::string& file_uri) = 0;
   
   static Glib::ustring get_conf_fullkey(const Glib::ustring& key);
 
