@@ -62,12 +62,12 @@ public:
   virtual Glib::ustring get_contents() const;
   virtual void set_contents(const Glib::ustring& strVal);
 
-  virtual Glib::ustring get_filepath() const;
-  virtual void set_filepath(const Glib::ustring& strVal, bool bEnforceFileExtension = false);
+  virtual Glib::ustring get_file_uri() const;
+  virtual void set_file_uri(const Glib::ustring& file_uri, bool bEnforceFileExtension = false);
 
-  ///Gets filename part of filepath, or 'untitled'.
+  ///Gets filename part of file_uri, or 'untitled'.
   virtual Glib::ustring get_name() const;
-  static Glib::ustring util_filepath_get_name(const Glib::ustring& filePath);
+  static Glib::ustring util_file_uri_get_name(const Glib::ustring& file_uri);
 
   virtual bool get_read_only() const;
   virtual void set_read_only(bool bVal);
@@ -111,7 +111,7 @@ protected:
   virtual bool write_to_disk();
 
   Glib::ustring m_strContents;
-  Glib::ustring m_strFilePath;
+  Glib::ustring m_file_uri;
   Glib::ustring m_strFileExtension;
 
   ViewBase* m_pView;
